@@ -3,7 +3,9 @@
 srcdir=`dirname $0`
 test -z "$srcdir" && srcdir=.
 
-pushd $srcdir
+olddir=`pwd`
+cd $srcdir
+
 
 accheck=`autoconf --version | grep 2.13`
 if test "x$accheck" != "x"; then
@@ -21,21 +23,22 @@ automake --version > /dev/null 2> /dev/null || {
     exit 1
 }
 
-automake --version | perl -ne 'if (/\(GNU automake\) ([0-9].[0-9])/) {print;  if ($1 < 1.6) {exit 1;}}'
+automake --version | perl -ne 'if (/\(GNU automake\) (([0-9]+).([0-9]+))/) {print; if ($2 < 1 || ($2 == 1 && $3 < 4)) {exit 1;}}'
 if [ $? -ne 0 ]; then
     echo "warning: you appear to be using automake <= 1.5"
     echo "         these versions have bugs - GNUmakefile.am dependencies are not generated"
 fi
 
-libtoolize --force --copy || {
-    echo "error: libtoolize failed"
-    exit 1
-}
 aclocal $ACLOCAL_FLAGS || {
     echo "error: aclocal $ACLOCAL_FLAGS failed"
     exit 1
 }
 
+libtoolize --force --copy || {
+    echo "error: libtoolize failed"
+    exit 1
+}
+
 echo "Checking for PKG_CHECK_MODULES..."
 
 pkgcheckdef=`grep PKG_CHECK_MODULES aclocal.m4 | grep AC_DEFUN`
@@ -73,7 +76,7 @@ autoconf || {
     exit 1
 }
 
-popd
+cd $olddir
 
 conf_flags="--enable-maintainer-mode"
 
