@@ -1,3 +1,22 @@
+/* wvWare
+ * Copyright (C) Caolan McNamara, Dom Lachowicz, and others
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -19,7 +38,7 @@ prepare_key (unsigned char *key_data_ptr, int key_data_len, rc4_key * key)
     unsigned char index1;
     unsigned char index2;
     unsigned char *state;
-    unsigned char counter;
+    unsigned int counter;
 
     state = &key->state[0];
     for (counter = 0; counter < 256; counter++)
@@ -44,7 +63,7 @@ rc4 (unsigned char *buffer_ptr, int buffer_len, rc4_key * key)
     unsigned char y;
     unsigned char *state;
     unsigned char xorIndex;
-    short counter;
+    unsigned int counter;
 
     x = key->x;
     y = key->y;
